@@ -12,6 +12,15 @@
 "K1p" <-
 function(S=35,T=25,P=0){
 
+nK <- max(length(S), length(T), length(P))
+
+##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
+
+if(length(S)!=nK){S <- rep(S[1], nK)}
+if(length(T)!=nK){T <- rep(T[1], nK)}
+if(length(P)!=nK){P <- rep(P[1], nK)}
+
+
 #-------Constantes----------------
 
 #---- issues de equic----
@@ -36,7 +45,8 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 	
 	K1P = exp(lnK1P);
 	
-		if (P > 0.0)
+for(i in (1:nK)){
+		if (P[i] > 0.0)
 		{
 		
 		RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
@@ -72,16 +82,18 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 		
 		for (ipc in 1:length(a0))
 		{
-		  deltav[ipc]  =  a0[ipc] + a1[ipc] *T + a2[ipc] *T*T;
-		  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T + b2[ipc] *T*T);  
-		  lnkpok0[ipc]  = -(deltav[ipc] /(R*TC))*P + (0.5*deltak[ipc] /(R*TC))*P*P;
+		  deltav[ipc]  =  a0[ipc] + a1[ipc] *T[i] + a2[ipc] *T[i]*T[i];
+		  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T[i] + b2[ipc] *T[i]*T[i]);  
+		  lnkpok0[ipc]  = -(deltav[ipc] /(R*TC[i]))*P[i] + (0.5*deltak[ipc] /(R*TC[i]))*P[i]*P[i];
 		}
 		
-		K1P = K1P*exp(lnkpok0[9]);
+		K1P[i] = K1P[i]*exp(lnkpok0[9]);
 
 		
 	}
-	attr(Ksi,"unit")     = "mol/kg-soln"
-	attr(Ksi,"pH scale") = "total hydrogen ion concentration"
+}
+
+	attr(K1P,"unit")     = "mol/kg-soln"
+	attr(K1P,"pH scale") = "total hydrogen ion concentration"
 	return(K1P)
 }
