@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Jean-Pierre Gattuso and Héloïse Lavigne and Aurelien Proye
+# Copyright (C) 2008 Jean-Pierre Gattuso and Héloïse Lavigne and Aurélien Proye
 #
 # This file is part of seacarb.
 #
@@ -13,6 +13,14 @@
 "Kb" <-
 function(S=35,T=25,P=0){
 
+nK <- max(length(S), length(T), length(P))
+
+##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
+
+if(length(S)!=nK){S <- rep(S[1], nK)}
+if(length(T)!=nK){T <- rep(T[1], nK)}
+if(length(P)!=nK){P <- rep(P[1], nK)}
+
 	
 #-------Constantes----------------
 
@@ -45,8 +53,9 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 	Kb <- exp(lnKb)
 
 	# ------------------- Pression effect --------------------------------
-		if (P > 0.0)
-		{
+		for(i in (1:nK)){		
+
+		if (P[i] > 0.0){
 		
 		RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
 		R = 83.131;             # mol bar deg-1 
@@ -81,15 +90,16 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 		
 		for (ipc in 1:length(a0))
 		{
-		  deltav[ipc]  =  a0[ipc] + a1[ipc] *T + a2[ipc] *T*T;
-		  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T + b2[ipc] *T*T);  
-		  lnkpok0[ipc]  = -(deltav[ipc] /(R*TK))*P + (0.5*deltak[ipc] /(R*TK))*P*P;
+		  deltav[ipc]  =  a0[ipc] + a1[ipc] *T[i] + a2[ipc] *T[i]*T[i];
+		  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T[i] + b2[ipc] *T[i]*T[i]);  
+		  lnkpok0[ipc]  = -(deltav[ipc] /(R*TK[i]))*P[i] + (0.5*deltak[ipc] /(R*TK[i]))*P[i]*P[i];
 		}
 		
 
-		Kb = Kb*exp(lnkpok0[3])
+		Kb[i] = Kb[i]*exp(lnkpok0[3])
 
 	}	
+}
 	attr(Kb,"unit")     = "mol/kg-soln"
 	attr(Kb,"pH scale") = "total hydrogen ion concentration"
 	return(Kb)
