@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Jean-Pierre Gattuso and Aurelien Proye
+# Copyright (C) 2008 Jean-Pierre Gattuso and Héloïse Lavigne and Aurélien Proye
 #
 # This file is part of seacarb.
 #
@@ -10,14 +10,22 @@
 #
 #
 "Kf" <-
-function(S=35,T=25,P=0,phflag=0){
+function(S=35,T=25,P=0,kf='pf'){
 
+nK <- max(length(S), length(T), length(P), length(kf))
 
+##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
+
+if(length(S)!=nK){S <- rep(S[1], nK)}
+if(length(T)!=nK){T <- rep(T[1], nK)}
+if(length(P)!=nK){P <- rep(P[1], nK)}
+if(length(kf)!=nK){kf <- rep(kf[1], nK)}
+ 
 #-------Constantes----------------
 
 #---- issues de equic----
 tk = 273.15;           # [K] (for conversion [deg C] <-> [K])
-TC = T + tk;           # TC [C]; T[K]
+TK = T + tk;           # TC [C]; T[K]
 Cl = S / 1.80655;      # Cl = chlorinity; S = salinity (per mille)
 cl3 = Cl^(1/3);   
 ION = 0.00147 + 0.03592 * Cl + 0.000068 * Cl * Cl;   # ionic strength
@@ -25,76 +33,62 @@ iom0 = 19.924*S/(1000-1.005*S);
 ST = 0.14/96.062/1.80655*S;   # (mol/kg soln) total sulfate
 
 
-bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94   
+bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94 
 
-	
-	
-	
-	#--------------------------------------------------------------
-	#------------------ Ks ----------------------------------------
-	#       Dickson and Goyet (1994), Chapter 5, p.13
-	#       (required for total2free)
-	#       Equilibrium constant for HSO4- = H+ + SO4--
-	#
-	#       K_S  = [H+]free [SO4--] / [HSO4-]
-	#       pH-scale: free scale !!!
-	#
-	#       the term log(1-0.001005*S) converts from
-	#       mol/kg H2O to mol/kg soln
-		
-		
-	tmp1 = -4276.1 / TC + 141.328 -23.093*log(TC);
-	tmp2 = +(-13856 / TC + 324.57 - 47.986 * log(TC))*sqrt(iom0);
-	tmp3 = +(35474 / TC - 771.54 + 114.723 * log(TC))*iom0;
-	tmp4 = -2698 / TC *sqrt(iom0)*iom0 + 1776 / TC *iom0 *iom0;
-	                                       
-	
-	lnKs = tmp1 + tmp2 + tmp3 + tmp4 + log(1-0.001005*S);
-	
-	Ks = exp(lnKs);
-	#------- total2free -----------------------------------------------
-	#
-	#       convert from pH_total ('total`) to pH ('free`):
-	#       pH_total = pH_free - log(1+ST/KS(s,tk))
-	
-	total2free = 1+ST/Ks;
-	
-	
-	
-	#---------------------------------------------------------------------
-	# --------------------- Kf  ------------------------------------------
-	#  Kf = [H+][F-]/[HF]  
-	#
-	#   (Dickson and Riley, 1979 in Dickson and Goyet, 
-	#   1994, Chapter 5, p. 14)
-	#   pH-scale: 'total'   
-	
-	
-	tmp1 = 1590.2/TC - 12.641 + 1.525*sqrt(ION);
-	tmp2 = log(1-0.001005*S) + log(1+ST/Ks);
-	
-	
-	lnKf = tmp1 + tmp2;
-	if (phflag == 0)
-	{
-	        Kf  = exp(lnKf);
-	}
-	if (phflag == 1)
-	{
-	        lnKf = lnKf-log(total2free);
-	        Kf  = exp(lnKf);
-	}
+#---------------------------------------------------------------------
+#---------------------- Kf Perez and Fraga ---------------------------
+#  Kf = [H+][F-]/[HF]  
+#
+#   Perez and Fraga, 1987 in Guide to the Best Practices for Ocean CO2 Measurements
+#   Dickson, Sabin and Christian , 2007, Chapter 5, p. 14)
+#  
+#   pH-scale: 'total'   
 
-	if (P > 0.0)
-	{
-	
+
+lnKfpf <- 874/TK - 9.68 + 0.111*S^(1/2)
+
+Kfpf <- exp(lnKfpf)
+
+
+#---------------------------------------------------------------------
+# --------------------- Kf Dickson and Goyet -------------------------
+#  Kf = [H+][F-]/[HF]  
+#
+#   (Dickson and Riley, 1979 in Dickson and Goyet, 
+#   1994, Chapter 5, p. 14)
+#   pH-scale: 'total' 
+
+
+Ks <- Ks(S=S, T=T, P=0)
+
+tmp1 = 1590.2/TK - 12.641 + 1.525*sqrt(ION);
+tmp2 = log(1-0.001005*S) + log(1+ST/Ks);
+lnKfdg = tmp1 + tmp2;
+
+Kfdg <- exp(lnKfdg)
+
+# ---------- Choice between methods (Perez and Dickson) ----------
+
+Kf <- Kfpf
+
+for(i in (1:nK)){
+if(kf[i]=='pf'){Kf[i] <- Kfpf[i]}
+if(kf[i]=='dg'){Kf[i] <- Kfdg[i]}
+}
+
+# ------------------- Pression effect --------------------------------
+
+for(i in (1:nK)){
+if (P[i] > 0.0)
+{
+		
 	RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
 	R = 83.131;             # mol bar deg-1 
 	                        # conversion cm3 -> m3          *1.e-6
-                        #            bar -> Pa = N m-2  *1.e+5
+        	                  #            bar -> Pa = N m-2  *1.e+5
 	                        #                => *1.e-1 or *1/10
-	
-	
+		
+		
 	# index: K1 1, K2 2, Kb 3, Kw 4, Ks 5, Kf 6, Kspc 7, Kspa 8,
 	#        K1P 9, K2P 10, K3P 11
 	
@@ -106,8 +100,8 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 	#----- the signs (+,-) of coefficients in Millero 95 do not
 	#----- agree with Millero 79
 	
-	
-	
+		
+		
 	a0 = c(-25.5, -15.82, -29.48, -25.60, -18.03, -9.78, -48.76, -46, -14.51, -23.12, -26.57);
 	a1 = c(0.1271, -0.0219, 0.1622, 0.2324, 0.0466, -0.0090, 0.5304, 0.5304, 0.1211, 0.1758, 0.2020);
 	a2 = c(0.0, 0.0, 2.608*1e-3, -3.6246*1e-3, 0.316*1e-3, -0.942*1e-3, 0.0, 0.0, -0.321*1e-3, -2.647*1e-3, -3.042*1e-3);
@@ -121,15 +115,22 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 	
 	for (ipc in 1:length(a0))
 	{
-	  deltav[ipc]  =  a0[ipc] + a1[ipc] *T + a2[ipc] *T*T;
-	  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T + b2[ipc] *T*T);  
-	  lnkpok0[ipc]  = -(deltav[ipc] /(R*TC))*P + (0.5*deltak[ipc] /(R*TC))*P*P;
-	}
-	
-	Kf = Kf*exp(lnkpok0[6]);
-	
+	  deltav[ipc]  =  a0[ipc] + a1[ipc] *T[i] + a2[ipc] *T[i]*T[i];
+	  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T[i] + b2[ipc] *T[i]*T[i]);  
+	  lnkpok0[ipc]  = -(deltav[ipc] /(R*TK[i]))*P[i] + (0.5*deltak[ipc] /(R*TK[i]))*P[i]*P[i];
 	}
+
+	Kf[i] <- Kf[i]*exp(lnkpok0[6])
+}
+}
+
+
 attr(Kf,"unit")     = "mol/kg-soln"
 attr(Kf,"pH scale") = "total hydrogen ion concentration"
 return(Kf)
 }
+
+
+
+
+
